@@ -48,9 +48,9 @@ public:
 
     void remove(const Akonadi::Item &item) Q_DECL_OVERRIDE;
     void remove(const Akonadi::Collection &collection) Q_DECL_OVERRIDE;
-    void move(const Akonadi::Item::Id &itemId,
-              const Akonadi::Collection::Id &from,
-              const Akonadi::Collection::Id &to) Q_DECL_OVERRIDE;
+    void move(Akonadi::Item::Id itemId,
+              Akonadi::Collection::Id from,
+              Akonadi::Collection::Id to) Q_DECL_OVERRIDE;
 private:
     void processPart(KMime::Content *content, KMime::Content *mainContent);
     void process(const KMime::Message::Ptr &msg);
